***********************************
******** Replication Do file ******
********    Public Choice    ******
********     STATA v. 16     ******  
***********************************

use dataset.dta, clear

sort gid year

gen lnum_trans = ln(num_trans + 1)
gen lnum_domestic = ln(num_domestic + 1)

gen ldu = ln(duration)
gen duration2 = duration^2

global x1 lpop lgdppc democracy civilconflict lmil  
global x2 diversity num_kidnap ldu 
global x3 diversity ldu
global x4 num_kidnap ldu
global x5 ldu


********************************
*******     Table 1    *********
********************************

eststo clear
estpost summarize num_domestic num_trans lconflict lgov_civil nliv_conflict  nliv_gc lpop lgdppc democracy ///
	civilconflict lmil diversity num_kidnap duration shr_trans dep nat left rel 


*****************************************************
*******     Table 2 & Table A2 & Table A3   *********
*****************************************************

*** Poisson control function
eststo clear
foreach var in rel nat left {

	eststo cont_c_`var'    : ivpoisson cfunc num_domestic (lconflict = nliv_conflict) $x1 $x2  if `var' == 1 ,nolog vce(cluster gid)
	test nliv_conflict
	
	eststo cont_gc_`var'   : ivpoisson cfunc num_domestic (lgov_civil = nliv_gc)      $x1 $x2  if `var' == 1 ,nolog vce(cluster gid) 	
	test nliv_gc
	}
estout *, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, fmt(%9.0g %9.3f)) // delete "eform" command for coefficients

**********************************
*******     Table A11    *********
**********************************

*** Poisson control function
eststo clear
foreach var in rel nat left {

	eststo cont_c_`var'    : ivpoisson cfunc num_domestic (lconflict = nliv_conflict) $x1 $x5  if `var' == 1 ,nolog vce(cluster gid)
	test nliv_conflict
	
	eststo cont_gc_`var'   : ivpoisson cfunc num_domestic (lgov_civil = nliv_gc)      $x1 $x5  if `var' == 1 ,nolog vce(cluster gid) 	
	test nliv_gc
	}
estout *, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, fmt(%9.0g %9.3f)) 

*****************************************************
*************     Table 3 & Table A4   **************
*****************************************************

*** Poisson control function
eststo clear
foreach var in rel nat left {

	eststo cont_c_`var'    : ivpoisson cfunc num_trans (lconflict = nliv_conflict) $x1 $x2  if `var' == 1 ,nolog vce(cluster gid)
	test nliv_conflict
	
	eststo cont_gc_`var'   : ivpoisson cfunc num_trans (lgov_civil = nliv_gc)      $x1 $x2  if `var' == 1 ,nolog vce(cluster gid) 	
	test nliv_gc
	
	}
estout *, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, fmt(%9.0g %9.3f)) // delete "eform" command for coefficients

**********************************
*******     Table A12    *********
**********************************

*** Poisson control function
eststo clear
foreach var in rel nat left {

	eststo cont_c_`var'    : ivpoisson cfunc num_trans (lconflict = nliv_conflict) $x1 $x5  if `var' == 1 ,nolog vce(cluster gid)
	test nliv_conflict
	
	eststo cont_gc_`var'   : ivpoisson cfunc num_trans (lgov_civil = nliv_gc)      $x1 $x5  if `var' == 1 ,nolog vce(cluster gid) 	
	test nliv_gc
	
	}
estout *, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, fmt(%9.0g %9.3f))

*****************************************************
******************     Table 5   ********************
*****************************************************

*** Poisson control function
eststo clear
foreach var in rel nat left {

	eststo cont_c_`var'    : ivpoisson cfunc num_domestic (lconflict = nliv_conflict) $x1 $x3  if `var' == 1 ,nolog vce(cluster gid)
	test nliv_conflict
	
	eststo cont_gc_`var'   : ivpoisson cfunc num_domestic (lgov_civil = nliv_gc)      $x1 $x3  if `var' == 1 ,nolog vce(cluster gid) 	
	test nliv_gc
	}
estout *, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, fmt(%9.0g %9.3f)) // delete "eform" command for coefficients

*****************************************************
******************     Table A10   ******************
*****************************************************

*** Poisson control function without kidnap
eststo clear
foreach var in rel nat left {

	eststo cont_c_`var'    : ivpoisson cfunc num_trans (lconflict = nliv_conflict) $x1 $x3  if `var' == 1 ,nolog vce(cluster gid)
	test nliv_conflict
	
	eststo cont_gc_`var'   : ivpoisson cfunc num_trans (lgov_civil = nliv_gc)      $x1 $x3  if `var' == 1 ,nolog vce(cluster gid) 	
	test nliv_gc
	
	}
estout *, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, fmt(%9.0g %9.3f)) // delete "eform" comman for coefficients


*****************************************************
*******           Table 4 & Table A9        *********
*****************************************************

*** Survival model
drop if right == 1

global x1 lpop lgdppc democracy lmil civilconflict  
global x2 diversity shr_trans num_kidnap duration duration2 nat left 

eststo clear

******Conflict aid
capture program drop logit_cf
program define logit_cf
	
	eststo n1: reg lconflict nliv_conflict $x1 $x2 , vce(cluster gid)
	predict lconflict_aid_res, residual
	
	logit dep lconflict lconflict_aid_res $x1 $x2, vce(cluster gid)
	drop lconflict_aid_res
end

eststo n1: bootstrap, reps(1010)  seed(12345) cluster(gid): logit_cf


******Government civil society aid
capture program drop logit_cf
program define logit_cf
	
	eststo n2: reg lgov_civil nliv_gc $x1 $x2, vce(cluster gid)
	predict lgc_aid_res, residual
	
	logit dep lgov_civil lgc_aid_res $x1 $x2, vce(cluster gid)
	drop lgc_aid_res
end

eststo n2: bootstrap, reps(1020)  seed(12345) cluster(gid): logit_cf

estout *, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, fmt(%9.0g %9.3f)) 

*****************************************************
************           Table 6        ***************
*****************************************************
global x2 diversity shr_trans duration duration2 nat left 
global x3 shr_trans num_kidnap duration duration2 nat left 
global x4 shr_trans duration duration2 nat left 
eststo clear

******Conflict aid without kidnap (Model 1)

eststo clear
capture program drop logit_cf
program define logit_cf
	
	eststo n1: reg lconflict nliv_conflict $x1 $x2, vce(cluster gid)
	predict lconflict_aid_res, residual
	
	logit dep lconflict lconflict_aid_res $x1 $x2, vce(cluster gid)
	drop lconflict_aid_res
end

eststo n1: bootstrap, reps(1010)  seed(12345) cluster(gid): logit_cf

******Conflict aid without diversity (Model 2)
capture program drop logit_cf
program define logit_cf
	
	eststo n2: reg lconflict nliv_conflict $x1 $x3, vce(cluster gid)
	predict lconflict_aid_res, residual
	
	logit dep lconflict lconflict_aid_res $x1 $x3, vce(cluster gid)
	drop lconflict_aid_res
end

eststo n2: bootstrap, reps(1010)  seed(12345) cluster(gid): logit_cf

******Conflict aid without both kidnap and diversity (Model 3)
capture program drop logit_cf
program define logit_cf
	
	eststo n3: reg lconflict nliv_conflict $x1 $x4, vce(cluster gid)
	predict lconflict_aid_res, residual
	
	logit dep lconflict lconflict_aid_res $x1 $x4, vce(cluster gid)
	drop lconflict_aid_res
end

eststo n3: bootstrap, reps(1010)  seed(12345) cluster(gid): logit_cf

******Government civil society aid without kidnap (Model 4)
capture program drop logit_cf
program define logit_cf
	
	eststo n4: reg lgov_civil nliv_gc $x1 $x2, vce(cluster gid)
	predict lgc_aid_res, residual
	
	logit dep lgov_civil lgc_aid_res $x1 $x2, vce(cluster gid)
	drop lgc_aid_res
end

eststo n4: bootstrap, reps(1020)  seed(12345) cluster(gid): logit_cf


******Government civil society aid without diversity (Model 5)
capture program drop logit_cf
program define logit_cf
	
	eststo n5: reg lgov_civil nliv_gc $x1 $x3, vce(cluster gid)
	predict lgc_aid_res, residual
	
	logit dep lgov_civil lgc_aid_res $x1 $x3, vce(cluster gid)
	drop lgc_aid_res
end

eststo n5: bootstrap, reps(1020)  seed(12345) cluster(gid): logit_cf

******Government civil society aid without both kidnap and diversity (Model 6)
capture program drop logit_cf
program define logit_cf
	
	eststo n6: reg lgov_civil nliv_gc $x1 $x4, vce(cluster gid)
	predict lgc_aid_res, residual
	
	logit dep lgov_civil lgc_aid_res $x1 $x4 , vce(cluster gid)
	drop lgc_aid_res
end

eststo n6: bootstrap, reps(1020)  seed(12345) cluster(gid): logit_cf

estout *, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, fmt(%9.0g %9.3f)) 

*********************************
*******   Figures 3   ***********
*********************************
quietly reg lgov_civil nliv_gc $x1 $x2 , vce(cluster gid)
quietly predict lgc_aid_res, residual
logit dep lgov_civil lgc_aid_res $x1 $x2 , vce(cluster gid)

eststo c1: margins, atmeans at(lgov_civil=(0(1)22) left=(0 1) nat=(0 1)) vsquish post
marginsplot
drop lgc_aid_res

**********************************
*******   Figures A1   ***********
**********************************
quietly reg lconflict nliv_conflict $x1 $x2 , vce(cluster gid)
quietly predict lconflict_aid_res, residual
quietly logit dep lconflict lconflict_aid_res $x1 $x2 , vce(cluster gid)
eststo c1: margins, atmeans at(lconflict=(0(1)22) left=(0 1) nat=(0 1)) vsquish post
marginsplot
drop lconflict_aid_res


***********************************************************
*****************     Other  Online Appendix **************
***********************************************************

**************************************
*******       Table A5       *********
**************************************

*** Negative binomial regression
eststo clear
foreach var in rel nat left {

	eststo pc`var'	   : nbreg num_domestic lconflict   $x1 $x2 if `var' == 1  , nolog vce(cluster gid)
	
	eststo pgc`var'	   : nbreg num_domestic lgov_civil  $x1 $x2 if `var' == 1  , nolog vce(cluster gid)
	
	}
estout *, cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, fmt(%9.0g %9.3f)) 

**************************************
*******       Table A6       *********
**************************************

*** Negative binomial regression
eststo clear
foreach var in rel nat left {

	eststo pc`var'	   : nbreg num_trans lconflict   $x1 $x2 if `var' == 1  , nolog vce(cluster gid)
	
	eststo pgc`var'	   : nbreg num_trans lgov_civil  $x1 $x2 if `var' == 1  , nolog vce(cluster gid)
	
	}
estout *, cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, fmt(%9.0g %9.3f)) 



**************************************
*******       Table A7       *********
**************************************
*** Linear IV
eststo clear
foreach var in rel nat left {

	eststo iv_c_`var'      : ivreg2 lnum_domestic (lconflict = nliv_conflict) $x1 $x2  if `var' == 1 , cluster(gid) first endog(lconflict)
	
	eststo iv_gc_`var'     : ivreg2 lnum_domestic (lgov_civil = nliv_gc) 	  $x1 $x2  if `var' == 1 , cluster(gid) first endog(lgov_civil)
	
	}
estout *, cells(b(star fmt(3)) se(par fmt(3)))  starlevels(* 0.10 ** 0.05 *** 0.01) stats(N ll r2 widstat idstat idp j jp, fmt(%9.0g %9.3f))

**************************************
*******       Table A8       *********
**************************************

***Linear IV
eststo clear
foreach var in rel nat left {

	eststo iv_c_`var'      : ivreg2 lnum_trans (lconflict = nliv_conflict) $x1 $x2  if `var' == 1 , cluster(gid) first endog(lconflict)
	
	eststo iv_gc_`var'     : ivreg2 lnum_trans (lgov_civil = nliv_gc) 	  $x1 $x2  if `var' == 1 , cluster(gid) first endog(lgov_civil)
	
	}
estout *, cells(b(star fmt(3)) se(par fmt(3)))  starlevels(* 0.10 ** 0.05 *** 0.01) stats(N ll r2 widstat idstat idp j jp, fmt(%9.0g %9.3f))


*********************************
******* Figures 1 & 2 ***********
*********************************
**number of incidents by ideologies

use dataset.dta, clear

collapse (sum) num_trans num_domestic, by(left nat rel right year)
